FixError

Enum FixError 

pub enum FixError {
    InvalidTag,
    InvalidUtf8,
    InvalidValue,
    IncompleteMessage,
    EncodeError,
    DecodeError,
    InvalidBodyLength,
    InvalidCheckSum,
}

Variants



InvalidTag

A tag field contained non-digit bytes or was otherwise malformed.



InvalidUtf8

A value field contained bytes that are not valid UTF-8.



InvalidValue

A numeric value field contained non-digit bytes.



IncompleteMessage

The buffer contains a partial FIX field; more bytes are needed (TCP framing).



EncodeError

An error occurred during message encoding.



DecodeError

An error occurred during message decoding.



InvalidBodyLength

Tag 9 (BodyLength) is absent, unparseable, or does not match the computed byte count.



InvalidCheckSum

Tag 10 (CheckSum) is absent, unparseable, or does not match the computed checksum.